style "theme-softwarecenter-text" = "theme-default" {
  GtkWidget::link-color = "#2485FF"
  GtkIMHtml::hyperlink-color = "#2485FF"
	GtkHTML::link-color = "#2485FF"
  fg[NORMAL]       	=  @text_color
  fg[PRELIGHT]     	=  @text_color
  fg[SELECTED]     	=  @text_color
  fg[ACTIVE]     	  =  @text_color
  fg[INSENSITIVE]   =  shade(0.5, @base_color)
  text[NORMAL]      =  @text_color
  text[PRELIGHT]    =  @text_color
  text[SELECTED]    =  @text_color
  text[ACTIVE]      =  @text_color
  text[INSENSITIVE] =  shade(0.5, @base_color)
  engine "equinox" {
    textstyle       = 0
  }
}
widget_class "*softwarecenter*.GtkVBox*<GtkLabel>"              style:highest "theme-softwarecenter-text"
widget_class "*softwarecenter*.GtkVBox*<GtkButton>.<GtkLabel>"  style:highest "theme-button"
style "theme-softwarecenter" = "theme-default" {
  bg[NORMAL]       	=  @base_color

}
widget_class "*softwarecenter*.GtkVBox" style:highest "theme-softwarecenter"

