style "theme-toolbar" = "theme-default" {
  bg[NORMAL] = shade(1.07, @bg_color)
  engine "equinox" {
    toolbarstyle        = 5
  }
}

style "theme-default" {
  engine "equinox" {
    menubarborders        = 0
    menubarstyle        = 0
  }
}

style "theme-panel-background" = "theme-panel" {
  bg_pixmap[NORMAL] = "images/panel_bg_global.png"
}

